SolverState

Struct SolverState 

pub struct SolverState {
    pub flows: Vec<f64>,
    pub heads: Vec<f64>,
    pub demands: Vec<f64>,
    pub emitter_flows: Vec<f64>,
    pub demand_flows: Vec<f64>,
    pub statuses: Vec<LinkStatus>,
    pub settings: Vec<f64>,
    pub resistances: Vec<f64>,
    pub topology_version: u32,
    pub properties_version: u32,
}
The solver state is the initial/final state of the solver for a single step

Fields

flows: Vec<f64>heads: Vec<f64>demands: Vec<f64>emitter_flows: Vec<f64>demand_flows: Vec<f64>statuses: Vec<LinkStatus>settings: Vec<f64>resistances: Vec<f64>topology_version: u32

version of the topology of the network on which the state was created

properties_version: u32

version of the properties of the network on which the state was created

Implementations

Source

impl SolverState

pub fn new_with_initial_values(network: &Network) -> Self

Create a new solver state with the initial values for the flows, heads, demands and statuses and calculate resistances

pub fn apply_patterns(&mut self, network: &Network, time: usize)

Applies demand and head patterns to the state at the given time. TODO: Add support for multiple patterns

pub fn apply_controls(&mut self, network: &Network, time: usize)

Applies controls to the state at the given time.

pub fn update_tanks(&mut self, network: &Network, timestep: usize)

Updates the tank levels for the given time step.

pub fn update_with_network_changes(&mut self, network: &mut Network)

Updates the state with the changes to the network.